@@ -29,6 +29,12 @@ if grep "^sshd:" etc/shadow 1> /dev/null 2> /dev/null ; then
 else
   echo "sshd:*:9797:0:::::" >> etc/shadow
 fi
+
+# Add a btmp file to store login failure if one doesn't exist:
+if [ ! -r var/log/btmp ]; then
+  ( cd var/log ; umask 077 ; touch btmp )
+fi
+
 ( cd usr/bin ; rm -rf slogin )
 ( cd usr/bin ; ln -sf ./ssh slogin )
 ( cd usr/man/man1 ; rm -rf slogin.1.gz )
